/***************************************************************************
 $RCSfile: jobgetbalance_be.h,v $
 -------------------
 cvs         : $Id: jobgetbalance_be.h,v 1.2 2006/02/14 02:11:54 aquamaniac Exp $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQBANKING_JOBGETBALANCE_BE_H
#define AQBANKING_JOBGETBALANCE_BE_H


#include <aqbanking/job.h>
#include <aqbanking/accstatus.h>
#include <aqbanking/jobgetbalance.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#endif /* AQBANKING_JOBGETBALANCE_BE_H */

